#!/bin/bash

CS_HOST_PORT="localhost:8080"
PROCESSED_DIR=/opt/cashserver
PROCESSED_ARCHIVE_DIR=/opt/backup
FILES_UPTIME=30

echo "date: $(date): begin backup..."

for directory in broken error processed; do
    echo "work with $directory"
    access_rule="$(stat -c%a $PROCESSED_DIR/$directory)"
    owner_rule="$(stat -c'%g:%G' $PROCESSED_DIR/$directory)"
    echo "access: $access_rule"
    echo "rule: $owner_rule"
    tar --remove-files -c $PROCESSED_DIR/$directory/ | gzip >  $PROCESSED_ARCHIVE_DIR/$(echo $directory)_archive/file-$(date +%y-%m-%d).tgz
    if [[ ! -d "$PROCESSED_DIR/$directory/" ]]; then
	echo "restore directory $directory"
	mkdir $PROCESSED_DIR/$directory
	chmod $access_rule $PROCESSED_DIR/$directory
	chown $owner_rule $PROCESSED_DIR/$directory
    fi;
#    zip -rm $PROCESSED_ARCHIVE_DIR/$(echo $directory)_archive/file-$(date +%d-%m-%y) $PROCESSED_DIR/$directory/*
    find $PROCESSED_ARCHIVE_DIR/$(echo $directory)_archive -mtime +$FILES_UPTIME -delete
done;

# remove archive dicts older than 1 month
dicts_dir=$(curl -s http://${CS_HOST_PORT}/CSrest/rest/propertys/SEND_DICTS_ON_CASHES_BY_URL_LOCAL_DIRECTORY | jq --raw-output '.value')

function deleteOldDictionary() {
    local actual_month=$(date --date="1 month ago" +"%m")
    local actual_day=$(date --date="1 month ago" +"%d")
    local actual_year=$(date --date="1 month ago" +"%Y")
    
    local archive_month=$(echo "$1" | cut -c3-4)
    local archive_day=$(echo "$1" | cut -c6-7)
    local archive_year=$(echo "$1" | cut -c9-12)
    
    local path=$(echo "$1" | cut -c3-12)

    if [ "${archive_year}" -lt "${actual_year}" ]; then 
        rm -rf $2/${path} 
    elif [ "${archive_year}" -eq "${actual_year}" ]; then
        if [ "${archive_month}" -lt "${actual_month}" ]; then
            rm -rf $2/${path} 
        elif [ "${archive_month}" -eq "${actual_month}" ]; then
            if [ "${archive_day}" -lt "${actual_day}" ]; then
                rm -rf $2/${path} 
            fi
        fi
    fi 
}

if [ ! -z $dicts_dir ]; then
    archive_dicts_dir=$dicts_dir/archive
    echo "clear from ${archive_dicts_dir}"
    export -f deleteOldDictionary
    find $archive_dicts_dir -maxdepth 1 -type d -name "*-*-*" -execdir bash -c "deleteOldDictionary {} ${archive_dicts_dir}" \;
fi

echo "date: $(date): end backup..."
